summaryrefslogtreecommitdiffstats
path: root/chrome/browser/printing/printer_query.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/printing/printer_query.h')
-rw-r--r--chrome/browser/printing/printer_query.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/printing/printer_query.h b/chrome/browser/printing/printer_query.h
index 8810022..d1d054d 100644
--- a/chrome/browser/printing/printer_query.h
+++ b/chrome/browser/printing/printer_query.h
@@ -43,11 +43,11 @@ class PrinterQuery : public PrintJobWorkerOwner {
virtual int cookie() const { return cookie_; }
// Initializes the printing context. It is fine to call this function multiple
// times to reinitialize the settings. |parent_window| parameter will be the
// owner of the print setting dialog box. It is unused when
// |ask_for_user_settings| is DEFAULTS.
void GetSettings(GetSettingsAskParam ask_user_for_settings,
- gfx::NativeWindow parent_window,
+ gfx::NativeView parent_view,
int expected_page_count,
bool has_selection,
bool use_overlays,
@@ -43,11 +43,11 @@ class PrinterQuery : public PrintJobWorkerOwner {
virtual int cookie() const { return cookie_; }
// Initializes the printing context. It is fine to call this function multiple
- // times to reinitialize the settings. |parent_window| parameter will be the
- // owner of the print setting dialog box. It is unused when
+ // times to reinitialize the settings. |parent_view| parameter's window will
+ // be the owner of the print setting dialog box. It is unused when
// |ask_for_user_settings| is DEFAULTS.
void GetSettings(GetSettingsAskParam ask_user_for_settings,